rail_button_drag_coefficient

Function rail_button_drag_coefficient 

pub fn rail_button_drag_coefficient(mach: f64) -> Result<f64, AeroError>
Parasitic drag coefficient of a rail button on its frontal area (the side profile of its base, waist and flange): Niskanen’s rail-pin rule (2009 p. 52), a pin drags like a solid launch lug as long as its diameter, (C_D•)_stag (Hoerner p. 5-8 gives 0.80 for a pin on a wall).

Errors

As stagnation_drag_coefficient.