#[non_exhaustive]pub struct ComponentDrag {
pub id: String,
pub drag: Drag,
}Expand description
One component’s share of the drag buildup, at zero lift.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe component’s id.
drag: DragIts drag. A step in radius belongs to the component aft of it, and the base to the last
body component; but a step down just behind a part whose drag is stated goes with that
part, whose aft face it is (ComponentDragTerms::fore_step_down_area_ratio). A stage’s
stated drag is listed under the stage’s id.