#[non_exhaustive]pub struct MergedBoattail {
pub through_aft: Boattail,
pub through_fore: Boattail,
pub area_ratio: f64,
pub weight: f64,
}Expand description
A narrowing transition’s share of a boattail it continues (BoattailTerm).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.through_aft: BoattailThe cone from the continued surface’s start through this transition’s aft end.
through_fore: BoattailThe cone from the same start through this transition’s fore end.
area_ratio: f64The cones’ fore area, at that start, over the reference area.
weight: f64This share’s part of the merge, from 0 to 1.