fin_count_factor

Function fin_count_factor 

pub fn fin_count_factor(count: u32) -> Result<f64, AeroError>
Fin–fin interference factor for count fins in one set (OpenRocket technical documentation 13.05 eq. 3.54, from MIL-HDBK-762(MI) p. 5-24): 1 up to four fins, then 0.948, 0.913, 0.854 and 0.810.

Errors

AeroError::Domain for no fins or more than eight: the documentation’s 0.750 for more than eight fins has no data behind it.