#[non_exhaustive]pub struct FinLoading {
pub slope_per_rad: f64,
pub cp_m: f64,
}Expand description
One fin’s normal-force slope and center of pressure at one Mach number.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.slope_per_rad: f64Normal-force slope per radian of the angle between the flow and the fin, on the reference area.
cp_m: f64Center of pressure, m aft of the root leading edge.