#[non_exhaustive]pub struct FinRoll {
pub forcing_per_rad: f64,
pub damping: f64,
}Expand description
One fin’s rolling moment at one Mach number, about the body axis, on the reference area
A_ref and diameter d (FinAero::roll); the body’s interference is the fin set’s
(roll_forcing_interference, roll_damping_interference).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.forcing_per_rad: f64∂C_l/∂δ per radian of the fin’s incidence, its cant, in the sense its lift turns the
rocket: positive.
damping: f64C_lp = ∂C_l/∂(p d/2V), per unit of the roll rate p made dimensionless by the airspeed
V: it opposes the roll, so it is negative.