FinSetAero

Struct FinSetAero 

#[non_exhaustive]
pub struct FinSetAero {
Show 13 fields pub id: String, pub count: u32, pub base_angle_rad: f64, pub fin: FinAero, pub count_factor: f64, pub interference: f64, pub fore_station_m: f64, pub cant_rad: f64, pub body_radius_m: f64, pub roll_forcing_interference: f64, pub roll_damping_interference: f64, pub roll: FinRollTerms, pub pods: Option<PodFins>,
}
A fin set’s precomputed terms.

Serialize-only, like AeroModel.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: String

The component’s id.

count: u32

Number of fins.

base_angle_rad: f64

Roll angle of the first fin, rad.

fin: FinAero

One fin’s normal force through the speed regimes, and its geometry.

count_factor: f64

Fin–fin factor f_N.

interference: f64

Fin–body interference K_T(B).

fore_station_m: f64

Station of the fins’ root leading edge, m aft of the nose tip.

cant_rad: f64

Cant, rad: positive turns fin 0’s leading edge toward −y_B (hpr_design::FinSet).

body_radius_m: f64

Radius of the body tube at the fins, m.

roll_forcing_interference: f64

The body’s interference with the roll forcing, k_T(B) (roll_forcing_interference).

roll_damping_interference: f64

The body’s interference with the roll damping, k_R(B) (roll_damping_interference).

roll: FinRollTerms

One fin’s roll terms on this body (FinAero::roll_terms).

pods: Option<PodFins>

For a fin set in a pod set, its copies: one per pod. None for the airframe’s.

Implementations

Source

impl FinSetAero

pub fn cp_station_m(&self, mach: f64) -> Result<f64, AeroError>

The set’s center of pressure at mach, m aft of the nose tip.

Errors

As FinAero::loading.