#[non_exhaustive]pub enum BodySegment {
Profile {
profile: Profile,
},
Cylinder {
length_m: f64,
radius_m: f64,
},
SphericalCap {
radius_m: f64,
length_m: f64,
},
}Expand description
One piece of a body of revolution, listed from the nose aft.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Profile
A nose cone (the first segment, pointed or with a vertical tip) or a transition.
Cylinder
A cylinder.
SphericalCap
A sphere’s cap from its pole, the first segment of a sphere-cone: the first length_m of
a sphere of radius_m, up to a hemisphere. Its tip is blunt, so the body flies
TN D-4865’s Newtonian cap ahead of the method (crate::blunt_tip).